Index: trunk/psLib/src/astro/psCoord.c
===================================================================
--- trunk/psLib/src/astro/psCoord.c	(revision 4321)
+++ trunk/psLib/src/astro/psCoord.c	(revision 4330)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.75 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-06-20 22:42:29 $
+*  @version $Revision: 1.76 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-06-21 03:01:37 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -221,5 +221,5 @@
 }
 
-psPlaneTransform* psPlaneTransformAlloc(psS32 n1, psS32 n2)
+psPlaneTransform* psPlaneTransformAlloc(int n1, int n2)
 {
     PS_ASSERT_INT_NONNEGATIVE(n1, NULL);
@@ -290,6 +290,6 @@
                              const psPlaneDistort* transform,
                              const psPlane* coords,
-                             float color,
-                             float magnitude)
+                             float mag,
+                             float color)
 {
     PS_ASSERT_PTR_NON_NULL(transform, NULL);
@@ -305,6 +305,6 @@
                  coords->x,
                  coords->y,
-                 color,
-                 magnitude
+                 mag,
+                 color
              );
     out->y = psDPolynomial4DEval(
@@ -312,6 +312,6 @@
                  coords->x,
                  coords->y,
-                 color,
-                 magnitude
+                 mag,
+                 color
              );
     return (out);
@@ -481,8 +481,8 @@
 
 psProjection* psProjectionAlloc(
-    psF64 R,
-    psF64 D,
-    psF64 Xs,
-    psF64 Ys,
+    double R,
+    double D,
+    double Xs,
+    double Ys,
     psProjectionType type)
 {
Index: trunk/psLib/src/astro/psCoord.h
===================================================================
--- trunk/psLib/src/astro/psCoord.h	(revision 4321)
+++ trunk/psLib/src/astro/psCoord.h	(revision 4330)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.35 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-06-20 22:42:29 $
+*  @version $Revision: 1.36 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-06-21 03:01:37 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -188,6 +188,6 @@
 
 psPlaneTransform* psPlaneTransformAlloc(
-    psS32 n1,  ///< The order of the x term in the transform.
-    psS32 n2   ///< The order of the y term in the transform.
+    int n1,                            ///< The order of the x term in the transform.
+    int n2                             ///< The order of the y term in the transform.
 );
 
@@ -223,6 +223,6 @@
     const psPlaneDistort* transform,   ///< the transform to apply
     const psPlane* coords,             ///< the coordinate to apply the transform above.
-    float term3,                       ///< third term -- maybe magnitude
-    float term4                        ///< forth term -- maybe color
+    float mag,                         ///< third term -- maybe magnitude
+    float color                        ///< forth term -- maybe color
 );
 
@@ -283,8 +283,8 @@
  */
 psProjection* psProjectionAlloc(
-    psF64 R,                   ///< Right-ascension of projection center.
-    psF64 D,                   ///< Declination of projection center.
-    psF64 Xs,                  ///< Scale in x-dimension
-    psF64 Ys,                  ///< Scale in y-dimension
+    double R,                   ///< Right-ascension of projection center.
+    double D,                   ///< Declination of projection center.
+    double Xs,                  ///< Scale in x-dimension
+    double Ys,                  ///< Scale in y-dimension
     psProjectionType type
 );
Index: trunk/psLib/src/astro/psTime.c
===================================================================
--- trunk/psLib/src/astro/psTime.c	(revision 4321)
+++ trunk/psLib/src/astro/psTime.c	(revision 4330)
@@ -10,6 +10,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.63 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-10 18:09:12 $
+ *  @version $Revision: 1.64 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-21 03:01:37 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -731,5 +731,5 @@
 }
 
-psF64 psTimeToLMST(psTime *time, psF64 longitude)
+double psTimeToLMST(psTime *time, double longitude)
 {
     psF64  jdTdtDays    =  0.0;
@@ -804,5 +804,5 @@
 }
 
-psF64 psTimeGetUT1Delta(const psTime *time, psTimeBulletin bulletin)
+double psTimeGetUT1Delta(const psTime *time, psTimeBulletin bulletin)
 {
     psU32              nTables               = 2;
@@ -1081,5 +1081,5 @@
 }
 
-psS64 psTimeLeapSecondDelta(const psTime *time1, const psTime *time2)
+long psTimeLeapSecondDelta(const psTime *time1, const psTime *time2)
 {
     psS64 diff = 0;
@@ -1095,5 +1095,5 @@
 }
 
-psBool psTimeIsLeapSecond(const psTime* utc)
+bool psTimeIsLeapSecond(const psTime* utc)
 {
     psTime*    prevUtc     = NULL;
@@ -1126,5 +1126,5 @@
 }
 
-psF64 psTimeToJD(const psTime *time)
+double psTimeToJD(const psTime *time)
 {
     psF64 jd = NAN;
@@ -1146,5 +1146,5 @@
 }
 
-psF64 psTimeToMJD(const psTime *time)
+double psTimeToMJD(const psTime *time)
 {
     psF64 mjd = NAN;
@@ -1302,5 +1302,5 @@
 */
 
-psTime* psTimeFromJD(psF64 time)
+psTime* psTimeFromJD(double jd)
 {
     psF64 days = 0.0;
@@ -1312,5 +1312,5 @@
 
     // Julian date conversion courtesy of Eugene Magnier
-    days = time - 2440587.5;
+    days = jd - 2440587.5;
     seconds = days * SEC_PER_DAY;
     if(seconds < 0.0) {
@@ -1327,5 +1327,5 @@
 }
 
-psTime* psTimeFromMJD(psF64 time)
+psTime* psTimeFromMJD(double mjd)
 {
     psF64 days = 0.0;
@@ -1337,5 +1337,5 @@
 
     // Modified Julian date conversion courtesy of Eugene Magnier
-    days = time - 40587.0;
+    days = mjd - 40587.0;
     seconds = days * SEC_PER_DAY;
 
@@ -1406,5 +1406,5 @@
 }
 
-psTime* psTimeFromUTC(psS64 sec, psU32 nsec, psBool leapsecond)
+psTime* psTimeFromUTC(psS64 sec, psU32 nsec, bool leapsecond)
 {
     psTime*   outTime   = NULL;
@@ -1510,5 +1510,5 @@
 }
 
-psTime* psTimeMath(const psTime *time, psF64 delta)
+psTime* psTimeMath(const psTime *time, double delta)
 {
     psF64 sec = 0.0;
@@ -1551,5 +1551,5 @@
 }
 
-psF64 psTimeDelta(const psTime *time1, const psTime *time2)
+double psTimeDelta(const psTime *time1, const psTime *time2)
 {
     psF64 out = 0.0;
Index: trunk/psLib/src/astro/psTime.h
===================================================================
--- trunk/psLib/src/astro/psTime.h	(revision 4321)
+++ trunk/psLib/src/astro/psTime.h	(revision 4330)
@@ -11,6 +11,6 @@
  *  @author Ross Harman, MHPCC
  *
- *  @version $Revision: 1.31 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2005-06-17 00:10:59 $
+ *  @version $Revision: 1.32 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2005-06-21 03:01:37 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -127,9 +127,9 @@
  *  in UTC format, then it is converted.
  *
- *  @return  psF64: LST Time.
- */
-psF64 psTimeToLMST(
-    psTime *time,                       ///< psTime to be converted.
-    psF64 longitude                    ///< Longitude.
+ *  @return  double: LST Time.
+ */
+double psTimeToLMST(
+    psTime *time,                      ///< psTime to be converted.
+    double longitude                    ///< Longitude.
 );
 
@@ -138,7 +138,7 @@
  *  This function is necessary to for various SLALIB functions.
  *
- *  @return  psF64: Time difference.
- */
-psF64 psTimeGetUT1Delta(
+ *  @return  double: Time difference.
+ */
+double psTimeGetUT1Delta(
     const psTime *time,                 ///< psTime to be looked up.
     psTimeBulletin bulletin             ///< IERS bulletin to use
@@ -169,9 +169,9 @@
  *  Calculates the number of leapseconds between two times.
  *
- *  @return  psS64: leapseconds added between given times
- */
-psS64 psTimeLeapSecondDelta(
-    const psTime* time1,                ///< First input time.
-    const psTime* time2                 ///< Second input time.
+ *  @return  long: leapseconds added between given times
+ */
+long psTimeLeapSecondDelta(
+    const psTime* time1,               ///< First input time.
+    const psTime* time2                ///< Second input time.
 );
 
@@ -180,7 +180,7 @@
  *  Determines if the specified UTC time is a valid leapsecond.
  *
- *  @return  psBool: valid leap second
- */
-psBool psTimeIsLeapSecond(
+ *  @return  bool: valid leap second
+ */
+bool psTimeIsLeapSecond(
     const psTime* utc                  ///< UTC to verify if leap second
 );
@@ -191,8 +191,8 @@
  *  subtract leapseconds.
  *
- *  @return  psF64: Julian Date (JD) time.
- */
-psF64 psTimeToJD(
-    const psTime* time                  ///< Input time to be converted.
+ *  @return  double: Julian Date (JD) time.
+ */
+double psTimeToJD(
+    const psTime* time                 ///< Input time to be converted.
 );
 /** Convert psTime to modified Julian date time.
@@ -201,7 +201,7 @@
  *  add or subtract leapseconds.
  *
- *  @return  psF64: Modified Julian Days (MJD) time.
- */
-psF64 psTimeToMJD(
+ *  @return  double: Modified Julian Days (MJD) time.
+ */
+double psTimeToMJD(
     const psTime* time                  ///< Input time to be converted.
 );
@@ -248,5 +248,5 @@
  */
 psTime* psTimeFromJD(
-    psF64 time                       ///< Input time to be converted.
+    double jd                          ///< Input time to be converted.
 );
 
@@ -258,5 +258,5 @@
  */
 psTime* psTimeFromMJD(
-    psF64 time                      ///< Input time to be converted.
+    double mjd                         ///< Input time to be converted.
 );
 
@@ -268,5 +268,5 @@
  */
 psTime* psTimeFromISO(
-    const char* time                 ///< Input time to be converted.
+    const char* time                   ///< Input time to be converted.
 );
 
@@ -278,5 +278,5 @@
  */
 psTime* psTimeFromTimeval(
-    const struct timeval *time       ///< Input time to be converted.
+    const struct timeval *time         ///< Input time to be converted.
 );
 
@@ -288,6 +288,6 @@
  */
 psTime* psTimeFromTT(
-    psS64 sec,                      ///< Input terrestrial time in seconds
-    psU32 nsec                      ///< Input terrestrial time fraction of seconds (nanoseconds)
+    psS64 sec,                         ///< Input terrestrial time in seconds
+    psU32 nsec                         ///< Input terrestrial time fraction of seconds (nanoseconds)
 );
 
@@ -299,7 +299,7 @@
  */
 psTime* psTimeFromUTC(
-    psS64  sec,                    ///< Input time in seconds
-    psU32  nsec,                   ///< Input time fraction of seconds (nanoseconds)
-    psBool leapsecond              ///< Input time is a leapsecond
+    psS64  sec,                        ///< Input time in seconds
+    psU32  nsec,                       ///< Input time fraction of seconds (nanoseconds)
+    bool leapsecond                    ///< Input time is a leapsecond
 );
 
@@ -313,5 +313,5 @@
  */
 psTime* p_psTimeFromTM(
-    const struct tm *time            ///< Input time to be converted.
+    const struct tm *time              ///< Input time to be converted.
 );
 
@@ -323,6 +323,6 @@
  */
 psTime* psTimeMath(
-    const psTime *time,              ///< Time.
-    psF64 delta                      ///< Time delta.
+    const psTime *time,                ///< Time.
+    double delta                       ///< Time delta.
 );
 
@@ -331,9 +331,9 @@
  *  Determine difference between two times. Input times are converted to TAI format if necessary.
  *
- *  @return psF64: Time difference.
- */
-psF64 psTimeDelta(
-    const psTime *time1,             ///< First time.
-    const psTime *time2              ///< Second time.
+ *  @return double: Time difference.
+ */
+double psTimeDelta(
+    const psTime *time1,               ///< First time.
+    const psTime *time2                ///< Second time.
 );
 
